tuplettools.Tuplet
==================

.. inheritance-diagram:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet
   :private-bases:

.. autoclass:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.contents_duration

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.duration_in_seconds

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.format

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_augmentation

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_binary

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_diminution

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_nonbinary

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_trivial

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.leaves

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.marks

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.multiplied_duration

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.music

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.override

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.parent

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.preprolated_duration

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.prolated_duration

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.prolation

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.ratio_string

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.set

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.spanners

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.force_fraction

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_invisible

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.is_parallel

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.multiplier

.. autoattribute:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.preferred_denominator

Methods
-------

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.append

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.extend

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.index

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.insert

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.pop

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.remove

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__add__

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__contains__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__delitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__getitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__iadd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__imul__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__len__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__mul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__radd__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__repr__

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__rmul__

   .. note:: Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__setitem__

   .. note:: Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.tuplettools.Tuplet.Tuplet.Tuplet.__str__
